@@ -32,8 +32,7 @@ Usage::
 from datetime import datetime
 from typing import Generic, Iterator, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import UsageLimitUsageTypeType
 from .type_defs import (
@@ -66,7 +65,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListEndpointAccessPaginator(Boto3Paginator):
+class ListEndpointAccessPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Paginator.ListEndpointAccess)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/paginators/#listendpointaccesspaginator)
@@ -85,7 +84,7 @@ class ListEndpointAccessPaginator(Boto3Paginator):
         """
 
 
-class ListNamespacesPaginator(Boto3Paginator):
+class ListNamespacesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Paginator.ListNamespaces)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/paginators/#listnamespacespaginator)
@@ -100,7 +99,7 @@ class ListNamespacesPaginator(Boto3Paginator):
         """
 
 
-class ListRecoveryPointsPaginator(Boto3Paginator):
+class ListRecoveryPointsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Paginator.ListRecoveryPoints)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/paginators/#listrecoverypointspaginator)
@@ -120,7 +119,7 @@ class ListRecoveryPointsPaginator(Boto3Paginator):
         """
 
 
-class ListSnapshotsPaginator(Boto3Paginator):
+class ListSnapshotsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Paginator.ListSnapshots)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/paginators/#listsnapshotspaginator)
@@ -142,7 +141,7 @@ class ListSnapshotsPaginator(Boto3Paginator):
         """
 
 
-class ListUsageLimitsPaginator(Boto3Paginator):
+class ListUsageLimitsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Paginator.ListUsageLimits)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/paginators/#listusagelimitspaginator)
@@ -161,7 +160,7 @@ class ListUsageLimitsPaginator(Boto3Paginator):
         """
 
 
-class ListWorkgroupsPaginator(Boto3Paginator):
+class ListWorkgroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-serverless.html#RedshiftServerless.Paginator.ListWorkgroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_redshift_serverless/paginators/#listworkgroupspaginator)
